@@ -21,7 +21,9 @@ import types
 from typing import Callable, Dict, Optional
 
 import click
+from click_option_group import optgroup
 from kfp import compiler
+from kfp.compiler.compiler_utils import KubernetesManifestOptions
 from kfp.dsl import base_component
 from kfp.dsl import graph_component
 from kfp.dsl.pipeline_context import Pipeline
@@ -140,6 +142,52 @@ def parse_parameters(parameters: Optional[str]) -> Dict:
     default=False,
     envvar='KFP_DISABLE_EXECUTION_CACHING_BY_DEFAULT',
     help='Whether to disable execution caching by default.')
+@click.option(
+    '--kubernetes-manifest-format',
+    is_flag=True,
+    default=False,
+    help='Output the compiled pipeline as a Kubernetes PipelineVersion manifest, with the option to include the Kubernetes Pipeline manifest as well when used with --include-pipeline-manifest.'
+)
+@optgroup.group(
+    'Kubernetes Manifest Options',
+    help='Options only used when compiling pipelines to Kubernetes native manifest format. These control the metadata of the generated Kubernetes resources. Only relevant if --kubernetes-manifest-format is set.'
+)
+@optgroup.option(
+    '--pipeline-name',
+    type=str,
+    default=None,
+    help='Name for the Pipeline resource. Only relevant if --kubernetes-manifest-format is set.'
+)
+@optgroup.option(
+    '--pipeline-display-name',
+    type=str,
+    default=None,
+    help='Display name for the Pipeline resource. Only relevant if --kubernetes-manifest-format is set.'
+)
+@optgroup.option(
+    '--pipeline-version-name',
+    type=str,
+    default=None,
+    help='Name for the PipelineVersion resource. Only relevant if --kubernetes-manifest-format is set.'
+)
+@optgroup.option(
+    '--pipeline-version-display-name',
+    type=str,
+    default=None,
+    help='Display name for the PipelineVersion resource. Only relevant if --kubernetes-manifest-format is set.'
+)
+@optgroup.option(
+    '--namespace',
+    type=str,
+    default=None,
+    help='Kubernetes namespace for the resources. Only relevant if --kubernetes-manifest-format is set.'
+)
+@optgroup.option(
+    '--include-pipeline-manifest',
+    is_flag=True,
+    default=False,
+    help='Include the Pipeline manifest in the output. Defaults to False. Only relevant if --kubernetes-manifest-format is set.'
+)
 def compile_(
     py: str,
     output: str,
@@ -147,6 +195,13 @@ def compile_(
     pipeline_parameters: Optional[str] = None,
     disable_type_check: bool = False,
     disable_execution_caching_by_default: bool = False,
+    kubernetes_manifest_format: bool = False,
+    pipeline_name: Optional[str] = None,
+    pipeline_display_name: Optional[str] = None,
+    pipeline_version_name: Optional[str] = None,
+    pipeline_version_display_name: Optional[str] = None,
+    namespace: Optional[str] = None,
+    include_pipeline_manifest: bool = False,
 ) -> None:
     """Compiles a pipeline or component written in a .py file."""
 
@@ -155,13 +210,39 @@ def compile_(
         python_file=py, function_name=function_name)
     parsed_parameters = parse_parameters(parameters=pipeline_parameters)
     package_path = os.path.join(os.getcwd(), output)
+
+    manifest_options_provided = any([
+        pipeline_name, pipeline_display_name, pipeline_version_name,
+        pipeline_version_display_name, namespace, include_pipeline_manifest
+    ])
+    kubernetes_manifest_options = None
+    if kubernetes_manifest_format:
+        kubernetes_manifest_options = KubernetesManifestOptions(
+            pipeline_name=pipeline_name,
+            pipeline_display_name=pipeline_display_name,
+            pipeline_version_name=pipeline_version_name,
+            pipeline_version_display_name=pipeline_version_display_name,
+            namespace=namespace,
+            include_pipeline_manifest=include_pipeline_manifest,
+        )
+    elif manifest_options_provided:
+        click.echo(
+            'Warning: Kubernetes manifest options were provided but --kubernetes-manifest-format was not set. '
+            'These options will be ignored.',
+            err=True)
+
     compiler.Compiler().compile(
         pipeline_func=pipeline_func,
         pipeline_parameters=parsed_parameters,
         package_path=package_path,
-        type_check=not disable_type_check)
+        type_check=not disable_type_check,
+        kubernetes_manifest_options=kubernetes_manifest_options,
+        kubernetes_manifest_format=kubernetes_manifest_format,
+    )
 
-    click.echo(package_path)
+    click.echo(
+        f'Pipeline code was successfully compiled with the output saved to {package_path}'
+    )
 
 
 def main():
