@@ -475,7 +475,7 @@ class Client:
                 namespace=namespace,
             )
             experiment = self._experiment_api.experiment_service_create_experiment(
-                body=experiment)
+                experiment=experiment)
 
         link = f'{self._get_url_prefix()}/#/experiments/details/{experiment.experiment_id}'
         if auth.is_ipython():
@@ -736,7 +736,7 @@ class Client:
             runtime_config=job_config.runtime_config,
             service_account=service_account)
 
-        response = self._run_api.run_service_create_run(body=run_body)
+        response = self._run_api.run_service_create_run(run=run_body)
 
         link = f'{self._get_url_prefix()}/#/runs/details/{response.run_id}'
         if auth.is_ipython():
@@ -907,7 +907,7 @@ class Client:
             max_concurrency=max_concurrency,
             service_account=service_account)
         return self._recurring_run_api.recurring_run_service_create_recurring_run(
-            body=job_body)
+            recurring_run=job_body)
 
     def _create_job_config(
         self,
@@ -1445,6 +1445,40 @@ class Client:
 
         return response
 
+    def upload_pipeline_from_pipeline_func(
+        self,
+        pipeline_func: base_component.BaseComponent,
+        pipeline_name: Optional[str] = None,
+        description: Optional[str] = None,
+        namespace: Optional[str] = None,
+    ) -> kfp_server_api.V2beta1Pipeline:
+        """Uploads a pipeline from a pipeline_func.
+
+        Args:
+            pipeline_func: Pipeline function constructed with ``@kfp.dsl.pipeline`` decorator.
+            pipeline_name: Name of the pipeline to be shown in the UI.
+            description: Description of the pipeline to be shown in the UI.
+            namespace: Optional. Kubernetes namespace where the pipeline should
+                be uploaded. For single user deployment, leave it as None; For
+                multi user, input a namespace where the user is authorized.
+
+        Returns:
+            ``V2beta1Pipeline`` object.
+        """
+        with tempfile.TemporaryDirectory() as tmpdir:
+            pipeline_package_path = os.path.join(tmpdir, 'pipeline.yaml')
+            compiler.Compiler().compile(
+                pipeline_func=pipeline_func,
+                package_path=pipeline_package_path,
+            )
+
+            return self.upload_pipeline(
+                pipeline_package_path=pipeline_package_path,
+                pipeline_name=pipeline_name,
+                description=description,
+                namespace=namespace,
+            )
+
     def upload_pipeline_version(
         self,
         pipeline_package_path: str,
@@ -1494,6 +1528,43 @@ class Client:
 
         return response
 
+    def upload_pipeline_version_from_pipeline_func(
+        self,
+        pipeline_func: base_component.BaseComponent,
+        pipeline_version_name: str,
+        pipeline_id: Optional[str] = None,
+        pipeline_name: Optional[str] = None,
+        description: Optional[str] = None,
+    ) -> kfp_server_api.V2beta1PipelineVersion:
+        """Uploads a new version of the pipeline.
+
+        Args:
+            pipeline_func: Pipeline function constructed with ``@kfp.dsl.pipeline`` decorator.
+            pipeline_version_name:  Name of the pipeline version to be shown in
+                the UI.
+            pipeline_id: ID of the pipeline.
+            pipeline_name: Name of the pipeline.
+            description: Description of the pipeline version to show in the UI.
+
+        Returns:
+            ``V2beta1PipelineVersion`` object.
+        """
+
+        with tempfile.TemporaryDirectory() as tmpdir:
+            pipeline_package_path = os.path.join(tmpdir, 'pipeline.yaml')
+            compiler.Compiler().compile(
+                pipeline_func=pipeline_func,
+                package_path=pipeline_package_path,
+            )
+
+            return self.upload_pipeline_version(
+                pipeline_package_path=pipeline_package_path,
+                pipeline_version_name=pipeline_version_name,
+                pipeline_id=pipeline_id,
+                pipeline_name=pipeline_name,
+                description=description,
+            )
+
     def get_pipeline(self, pipeline_id: str) -> kfp_server_api.V2beta1Pipeline:
         """Gets pipeline details.
 
