@@ -12,7 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 """Tests for pipeline_orchestrator.py."""
-
+import functools
 import io as stdlib_io
 import os
 from typing import NamedTuple
@@ -27,10 +27,30 @@ from kfp.dsl import Model
 from kfp.dsl import Output
 from kfp.dsl import pipeline_task
 from kfp.local import testing_utilities
+import pytest
 
 ROOT_FOR_TESTING = './testing_root'
 
 
+@pytest.fixture(autouse=True)
+def set_packages_for_test_classes(monkeypatch, request):
+    if request.cls.__name__ in {
+            'TestRunLocalPipeline',
+            'TestFstringContainerComponent',
+    }:
+        root_dir = os.path.dirname(
+            os.path.dirname(
+                os.path.dirname(os.path.dirname(os.path.dirname(__file__)))))
+        kfp_pipeline_spec_path = os.path.join(root_dir, 'api', 'v2alpha1',
+                                              'python')
+        original_dsl_component = dsl.component
+        monkeypatch.setattr(
+            dsl, 'component',
+            functools.partial(
+                original_dsl_component,
+                packages_to_install=[kfp_pipeline_spec_path]))
+
+
 class TestRunLocalPipeline(testing_utilities.LocalRunnerEnvironmentTestCase):
 
     def assert_output_dir_contents(
@@ -76,7 +96,7 @@ class TestRunLocalPipeline(testing_utilities.LocalRunnerEnvironmentTestCase):
     def test_no_io(self):
         local.init(local.SubprocessRunner(), pipeline_root=ROOT_FOR_TESTING)
 
-        @dsl.component
+        @dsl.component()
         def pass_op():
             pass
 
